@@ -1,21 +1,31 @@
 import logging
+from typing import Any, Iterable, Optional
 
 import requests
 
-from tilecloud import TileStore
+from tilecloud import Tile, TileLayout, TileStore
 
 logger = logging.getLogger(__name__)
 
 
 class URLTileStore(TileStore):
-    def __init__(self, tilelayouts, headers=None, **kwargs):
+    def __init__(
+        self,
+        tilelayouts: Iterable[TileLayout],
+        headers: Optional[Any] = None,
+        allows_no_contenttype: bool = False,
+        **kwargs: Any,
+    ) -> None:
         TileStore.__init__(self, **kwargs)
+        self.allows_no_contenttype = allows_no_contenttype
         self.tilelayouts = tuple(tilelayouts)
         self.session = requests.session()
         if headers is not None:
             self.session.headers.update(headers)
 
-    def get_one(self, tile):
+    def get_one(self, tile: Tile) -> Optional[Tile]:
+        if tile is None:
+            return None
         if self.bounding_pyramid is not None:
             if tile.tilecoord not in self.bounding_pyramid:
                 return None
@@ -29,16 +39,24 @@ class URLTileStore(TileStore):
         logger.info("GET %s", url)
         try:
             response = self.session.get(url)
-            if response.status_code == 404:
+            if response.status_code in (404, 204):
                 return None
             tile.content_encoding = response.headers.get("Content-Encoding")
             tile.content_type = response.headers.get("Content-Type")
             if response.status_code < 300:
-                tile.data = response.content
-                if tile.content_type.startswith("image/"):
-                    tile.data = response.content
+                if response.status_code != 200:
+                    tile.error = f"Unsupported status code {response.status_code}: {response.reason}"
+                if tile.content_type:
+                    if tile.content_type.startswith("image/"):
+                        tile.data = response.content
+                    else:
+                        tile.error = response.text
                 else:
-                    tile.error = response.text
+                    if self.allows_no_contenttype:
+                        tile.data = response.content
+                    else:
+                        tile.error = "The Content-Type header is missing"
+
             else:
                 tile.error = response.reason
         except requests.exceptions.RequestException as e:
